@@ -1,4 +1,4 @@
-/* Copyright (C) 2003-2005 Jesper K. Pedersen <blackie@kde.org>
+/* Copyright (C) 2003-2006 Jesper K. Pedersen <blackie@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -21,11 +21,15 @@
 
 #include <qdialog.h>
 #include <qimage.h>
-#include "imageinfoptr.h"
-class ImageInfo;
+#include "DB/ImageInfoPtr.h"
 class QCloseEvent;
 class QLabel;
 
+namespace DB
+{
+    class ImageInfo;
+}
+
 namespace ImportExport
 {
 
@@ -34,7 +38,7 @@ class MiniViewer :public QDialog
     Q_OBJECT
 
 public:
-    static void show( QImage img, ImageInfoPtr info );
+    static void show( QImage img, DB::ImageInfoPtr info );
     virtual void closeEvent( QCloseEvent* event );
 
 protected slots:
